pub struct Signature { /* private fields */ }Expand description
A Signature is a single signature found in a note.
Implementations
Sourceimpl Signature
impl Signature
Sourcepub fn new(name: String, id: u32, sig: Vec<u8>) -> Result<Self, NoteError>
pub fn new(name: String, id: u32, sig: Vec<u8>) -> Result<Self, NoteError>
Returns a new signature from the given name and base64-encoded signature string.
Errors
Returns NoteError::MalformedNote if the name is invalid according to is_key_name_valid.
Sourcepub fn from_bytes(line: &[u8]) -> Result<Self, NoteError>
pub fn from_bytes(line: &[u8]) -> Result<Self, NoteError>